@@ -5,11 +5,11 @@ package YAMLScript;
 
 use FFI::CheckLib ();
 use FFI::Platypus;
-use JSON ();
+use Cpanel::JSON::XS ();
 
-our $VERSION = '0.1.22';
+our $VERSION = '0.1.35';
 
-our $libyamlscript_version = '0.1.34';
+our $libyamlscript_version = '0.1.35';
 
 
 #------------------------------------------------------------------------------
@@ -71,7 +71,7 @@ $ffi->attach(
         my ($xsub, $self, $ys) = @_;
         $self->{error} = undef;
 
-        my $resp = JSON::decode_json(
+        my $resp = Cpanel::JSON::XS::decode_json(
             $xsub->(${$self->{isolatethread}}, $ys)
         );
 
